import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent, PromiseOrValue } from "../common";
export declare namespace IERC721A {
    type TokenOwnershipStruct = {
        addr: PromiseOrValue<string>;
        startTimestamp: PromiseOrValue<BigNumberish>;
        burned: PromiseOrValue<boolean>;
        extraData: PromiseOrValue<BigNumberish>;
    };
    type TokenOwnershipStructOutput = [
        string,
        BigNumber,
        boolean,
        number
    ] & {
        addr: string;
        startTimestamp: BigNumber;
        burned: boolean;
        extraData: number;
    };
}
export declare namespace IERC721M {
    type MintStageInfoStruct = {
        price: PromiseOrValue<BigNumberish>;
        mintFee: PromiseOrValue<BigNumberish>;
        walletLimit: PromiseOrValue<BigNumberish>;
        merkleRoot: PromiseOrValue<BytesLike>;
        maxStageSupply: PromiseOrValue<BigNumberish>;
        startTimeUnixSeconds: PromiseOrValue<BigNumberish>;
        endTimeUnixSeconds: PromiseOrValue<BigNumberish>;
    };
    type MintStageInfoStructOutput = [
        BigNumber,
        BigNumber,
        number,
        string,
        number,
        BigNumber,
        BigNumber
    ] & {
        price: BigNumber;
        mintFee: BigNumber;
        walletLimit: number;
        merkleRoot: string;
        maxStageSupply: number;
        startTimeUnixSeconds: BigNumber;
        endTimeUnixSeconds: BigNumber;
    };
}
export interface IERC721MInterface extends utils.Interface {
    functions: {
        "approve(address,uint256)": FunctionFragment;
        "authorizedMint(uint32,address,uint32,bytes32[],uint64,bytes)": FunctionFragment;
        "balanceOf(address)": FunctionFragment;
        "crossmint(uint32,address,bytes32[],uint64,bytes)": FunctionFragment;
        "explicitOwnershipOf(uint256)": FunctionFragment;
        "explicitOwnershipsOf(uint256[])": FunctionFragment;
        "getApproved(uint256)": FunctionFragment;
        "getCosignNonce(address)": FunctionFragment;
        "getGlobalWalletLimit()": FunctionFragment;
        "getMaxMintableSupply()": FunctionFragment;
        "getNumberStages()": FunctionFragment;
        "getStageInfo(uint256)": FunctionFragment;
        "isApprovedForAll(address,address)": FunctionFragment;
        "mint(uint32,bytes32[],uint64,bytes)": FunctionFragment;
        "mintWithLimit(uint32,uint32,bytes32[],uint64,bytes)": FunctionFragment;
        "name()": FunctionFragment;
        "ownerOf(uint256)": FunctionFragment;
        "safeTransferFrom(address,address,uint256)": FunctionFragment;
        "safeTransferFrom(address,address,uint256,bytes)": FunctionFragment;
        "setApprovalForAll(address,bool)": FunctionFragment;
        "supportsInterface(bytes4)": FunctionFragment;
        "symbol()": FunctionFragment;
        "tokenURI(uint256)": FunctionFragment;
        "tokensOfOwner(address)": FunctionFragment;
        "tokensOfOwnerIn(address,uint256,uint256)": FunctionFragment;
        "totalMintedByAddress(address)": FunctionFragment;
        "totalSupply()": FunctionFragment;
        "transferFrom(address,address,uint256)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "approve" | "authorizedMint" | "balanceOf" | "crossmint" | "explicitOwnershipOf" | "explicitOwnershipsOf" | "getApproved" | "getCosignNonce" | "getGlobalWalletLimit" | "getMaxMintableSupply" | "getNumberStages" | "getStageInfo" | "isApprovedForAll" | "mint" | "mintWithLimit" | "name" | "ownerOf" | "safeTransferFrom(address,address,uint256)" | "safeTransferFrom(address,address,uint256,bytes)" | "setApprovalForAll" | "supportsInterface" | "symbol" | "tokenURI" | "tokensOfOwner" | "tokensOfOwnerIn" | "totalMintedByAddress" | "totalSupply" | "transferFrom"): FunctionFragment;
    encodeFunctionData(functionFragment: "approve", values: [PromiseOrValue<string>, PromiseOrValue<BigNumberish>]): string;
    encodeFunctionData(functionFragment: "authorizedMint", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>[],
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>
    ]): string;
    encodeFunctionData(functionFragment: "balanceOf", values: [PromiseOrValue<string>]): string;
    encodeFunctionData(functionFragment: "crossmint", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>,
        PromiseOrValue<BytesLike>[],
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>
    ]): string;
    encodeFunctionData(functionFragment: "explicitOwnershipOf", values: [PromiseOrValue<BigNumberish>]): string;
    encodeFunctionData(functionFragment: "explicitOwnershipsOf", values: [PromiseOrValue<BigNumberish>[]]): string;
    encodeFunctionData(functionFragment: "getApproved", values: [PromiseOrValue<BigNumberish>]): string;
    encodeFunctionData(functionFragment: "getCosignNonce", values: [PromiseOrValue<string>]): string;
    encodeFunctionData(functionFragment: "getGlobalWalletLimit", values?: undefined): string;
    encodeFunctionData(functionFragment: "getMaxMintableSupply", values?: undefined): string;
    encodeFunctionData(functionFragment: "getNumberStages", values?: undefined): string;
    encodeFunctionData(functionFragment: "getStageInfo", values: [PromiseOrValue<BigNumberish>]): string;
    encodeFunctionData(functionFragment: "isApprovedForAll", values: [PromiseOrValue<string>, PromiseOrValue<string>]): string;
    encodeFunctionData(functionFragment: "mint", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>[],
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>
    ]): string;
    encodeFunctionData(functionFragment: "mintWithLimit", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>[],
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>
    ]): string;
    encodeFunctionData(functionFragment: "name", values?: undefined): string;
    encodeFunctionData(functionFragment: "ownerOf", values: [PromiseOrValue<BigNumberish>]): string;
    encodeFunctionData(functionFragment: "safeTransferFrom(address,address,uint256)", values: [
        PromiseOrValue<string>,
        PromiseOrValue<string>,
        PromiseOrValue<BigNumberish>
    ]): string;
    encodeFunctionData(functionFragment: "safeTransferFrom(address,address,uint256,bytes)", values: [
        PromiseOrValue<string>,
        PromiseOrValue<string>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>
    ]): string;
    encodeFunctionData(functionFragment: "setApprovalForAll", values: [PromiseOrValue<string>, PromiseOrValue<boolean>]): string;
    encodeFunctionData(functionFragment: "supportsInterface", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "symbol", values?: undefined): string;
    encodeFunctionData(functionFragment: "tokenURI", values: [PromiseOrValue<BigNumberish>]): string;
    encodeFunctionData(functionFragment: "tokensOfOwner", values: [PromiseOrValue<string>]): string;
    encodeFunctionData(functionFragment: "tokensOfOwnerIn", values: [
        PromiseOrValue<string>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>
    ]): string;
    encodeFunctionData(functionFragment: "totalMintedByAddress", values: [PromiseOrValue<string>]): string;
    encodeFunctionData(functionFragment: "totalSupply", values?: undefined): string;
    encodeFunctionData(functionFragment: "transferFrom", values: [
        PromiseOrValue<string>,
        PromiseOrValue<string>,
        PromiseOrValue<BigNumberish>
    ]): string;
    decodeFunctionResult(functionFragment: "approve", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "authorizedMint", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "balanceOf", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "crossmint", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "explicitOwnershipOf", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "explicitOwnershipsOf", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getApproved", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getCosignNonce", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getGlobalWalletLimit", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getMaxMintableSupply", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getNumberStages", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getStageInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isApprovedForAll", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "mint", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "mintWithLimit", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "name", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "ownerOf", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "safeTransferFrom(address,address,uint256)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "safeTransferFrom(address,address,uint256,bytes)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setApprovalForAll", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "supportsInterface", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "symbol", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "tokenURI", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "tokensOfOwner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "tokensOfOwnerIn", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "totalMintedByAddress", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "totalSupply", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferFrom", data: BytesLike): Result;
    events: {
        "Approval(address,address,uint256)": EventFragment;
        "ApprovalForAll(address,address,bool)": EventFragment;
        "ConsecutiveTransfer(uint256,uint256,address,address)": EventFragment;
        "SetActiveStage(uint256)": EventFragment;
        "SetBaseURI(string)": EventFragment;
        "SetCosigner(address)": EventFragment;
        "SetCrossmintAddress(address)": EventFragment;
        "SetGlobalWalletLimit(uint256)": EventFragment;
        "SetMaxMintableSupply(uint256)": EventFragment;
        "SetMintCurrency(address)": EventFragment;
        "SetMintable(bool)": EventFragment;
        "SetTimestampExpirySeconds(uint64)": EventFragment;
        "Transfer(address,address,uint256)": EventFragment;
        "UpdateStage(uint256,uint80,uint80,uint32,bytes32,uint24,uint64,uint64)": EventFragment;
        "Withdraw(uint256)": EventFragment;
        "WithdrawERC20(address,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "Approval"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "ApprovalForAll"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "ConsecutiveTransfer"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetActiveStage"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetBaseURI"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetCosigner"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetCrossmintAddress"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetGlobalWalletLimit"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetMaxMintableSupply"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetMintCurrency"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetMintable"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetTimestampExpirySeconds"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Transfer"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "UpdateStage"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Withdraw"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "WithdrawERC20"): EventFragment;
}
export interface ApprovalEventObject {
    owner: string;
    approved: string;
    tokenId: BigNumber;
}
export type ApprovalEvent = TypedEvent<[
    string,
    string,
    BigNumber
], ApprovalEventObject>;
export type ApprovalEventFilter = TypedEventFilter<ApprovalEvent>;
export interface ApprovalForAllEventObject {
    owner: string;
    operator: string;
    approved: boolean;
}
export type ApprovalForAllEvent = TypedEvent<[
    string,
    string,
    boolean
], ApprovalForAllEventObject>;
export type ApprovalForAllEventFilter = TypedEventFilter<ApprovalForAllEvent>;
export interface ConsecutiveTransferEventObject {
    fromTokenId: BigNumber;
    toTokenId: BigNumber;
    from: string;
    to: string;
}
export type ConsecutiveTransferEvent = TypedEvent<[
    BigNumber,
    BigNumber,
    string,
    string
], ConsecutiveTransferEventObject>;
export type ConsecutiveTransferEventFilter = TypedEventFilter<ConsecutiveTransferEvent>;
export interface SetActiveStageEventObject {
    activeStage: BigNumber;
}
export type SetActiveStageEvent = TypedEvent<[
    BigNumber
], SetActiveStageEventObject>;
export type SetActiveStageEventFilter = TypedEventFilter<SetActiveStageEvent>;
export interface SetBaseURIEventObject {
    baseURI: string;
}
export type SetBaseURIEvent = TypedEvent<[string], SetBaseURIEventObject>;
export type SetBaseURIEventFilter = TypedEventFilter<SetBaseURIEvent>;
export interface SetCosignerEventObject {
    cosigner: string;
}
export type SetCosignerEvent = TypedEvent<[string], SetCosignerEventObject>;
export type SetCosignerEventFilter = TypedEventFilter<SetCosignerEvent>;
export interface SetCrossmintAddressEventObject {
    crossmintAddress: string;
}
export type SetCrossmintAddressEvent = TypedEvent<[
    string
], SetCrossmintAddressEventObject>;
export type SetCrossmintAddressEventFilter = TypedEventFilter<SetCrossmintAddressEvent>;
export interface SetGlobalWalletLimitEventObject {
    globalWalletLimit: BigNumber;
}
export type SetGlobalWalletLimitEvent = TypedEvent<[
    BigNumber
], SetGlobalWalletLimitEventObject>;
export type SetGlobalWalletLimitEventFilter = TypedEventFilter<SetGlobalWalletLimitEvent>;
export interface SetMaxMintableSupplyEventObject {
    maxMintableSupply: BigNumber;
}
export type SetMaxMintableSupplyEvent = TypedEvent<[
    BigNumber
], SetMaxMintableSupplyEventObject>;
export type SetMaxMintableSupplyEventFilter = TypedEventFilter<SetMaxMintableSupplyEvent>;
export interface SetMintCurrencyEventObject {
    mintCurrency: string;
}
export type SetMintCurrencyEvent = TypedEvent<[
    string
], SetMintCurrencyEventObject>;
export type SetMintCurrencyEventFilter = TypedEventFilter<SetMintCurrencyEvent>;
export interface SetMintableEventObject {
    mintable: boolean;
}
export type SetMintableEvent = TypedEvent<[boolean], SetMintableEventObject>;
export type SetMintableEventFilter = TypedEventFilter<SetMintableEvent>;
export interface SetTimestampExpirySecondsEventObject {
    expiry: BigNumber;
}
export type SetTimestampExpirySecondsEvent = TypedEvent<[
    BigNumber
], SetTimestampExpirySecondsEventObject>;
export type SetTimestampExpirySecondsEventFilter = TypedEventFilter<SetTimestampExpirySecondsEvent>;
export interface TransferEventObject {
    from: string;
    to: string;
    tokenId: BigNumber;
}
export type TransferEvent = TypedEvent<[
    string,
    string,
    BigNumber
], TransferEventObject>;
export type TransferEventFilter = TypedEventFilter<TransferEvent>;
export interface UpdateStageEventObject {
    stage: BigNumber;
    price: BigNumber;
    mintFee: BigNumber;
    walletLimit: number;
    merkleRoot: string;
    maxStageSupply: number;
    startTimeUnixSeconds: BigNumber;
    endTimeUnixSeconds: BigNumber;
}
export type UpdateStageEvent = TypedEvent<[
    BigNumber,
    BigNumber,
    BigNumber,
    number,
    string,
    number,
    BigNumber,
    BigNumber
], UpdateStageEventObject>;
export type UpdateStageEventFilter = TypedEventFilter<UpdateStageEvent>;
export interface WithdrawEventObject {
    value: BigNumber;
}
export type WithdrawEvent = TypedEvent<[BigNumber], WithdrawEventObject>;
export type WithdrawEventFilter = TypedEventFilter<WithdrawEvent>;
export interface WithdrawERC20EventObject {
    mintCurrency: string;
    value: BigNumber;
}
export type WithdrawERC20Event = TypedEvent<[
    string,
    BigNumber
], WithdrawERC20EventObject>;
export type WithdrawERC20EventFilter = TypedEventFilter<WithdrawERC20Event>;
export interface IERC721M extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: IERC721MInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        approve(to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        authorizedMint(qty: PromiseOrValue<BigNumberish>, to: PromiseOrValue<string>, limit: PromiseOrValue<BigNumberish>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        balanceOf(owner: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[BigNumber] & {
            balance: BigNumber;
        }>;
        crossmint(qty: PromiseOrValue<BigNumberish>, to: PromiseOrValue<string>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        explicitOwnershipOf(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<[IERC721A.TokenOwnershipStructOutput]>;
        explicitOwnershipsOf(tokenIds: PromiseOrValue<BigNumberish>[], overrides?: CallOverrides): Promise<[IERC721A.TokenOwnershipStructOutput[]]>;
        getApproved(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<[string] & {
            operator: string;
        }>;
        getCosignNonce(minter: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[BigNumber]>;
        getGlobalWalletLimit(overrides?: CallOverrides): Promise<[BigNumber]>;
        getMaxMintableSupply(overrides?: CallOverrides): Promise<[BigNumber]>;
        getNumberStages(overrides?: CallOverrides): Promise<[BigNumber]>;
        getStageInfo(index: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<[IERC721M.MintStageInfoStructOutput, number, BigNumber]>;
        isApprovedForAll(owner: PromiseOrValue<string>, operator: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[boolean]>;
        mint(qty: PromiseOrValue<BigNumberish>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        mintWithLimit(qty: PromiseOrValue<BigNumberish>, limit: PromiseOrValue<BigNumberish>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        name(overrides?: CallOverrides): Promise<[string]>;
        ownerOf(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<[string] & {
            owner: string;
        }>;
        "safeTransferFrom(address,address,uint256)"(from: PromiseOrValue<string>, to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        "safeTransferFrom(address,address,uint256,bytes)"(from: PromiseOrValue<string>, to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, data: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        setApprovalForAll(operator: PromiseOrValue<string>, _approved: PromiseOrValue<boolean>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        supportsInterface(interfaceId: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[boolean]>;
        symbol(overrides?: CallOverrides): Promise<[string]>;
        tokenURI(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<[string]>;
        tokensOfOwner(owner: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[BigNumber[]]>;
        tokensOfOwnerIn(owner: PromiseOrValue<string>, start: PromiseOrValue<BigNumberish>, stop: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<[BigNumber[]]>;
        totalMintedByAddress(a: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[BigNumber]>;
        totalSupply(overrides?: CallOverrides): Promise<[BigNumber]>;
        transferFrom(from: PromiseOrValue<string>, to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
    };
    approve(to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    authorizedMint(qty: PromiseOrValue<BigNumberish>, to: PromiseOrValue<string>, limit: PromiseOrValue<BigNumberish>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    balanceOf(owner: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
    crossmint(qty: PromiseOrValue<BigNumberish>, to: PromiseOrValue<string>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    explicitOwnershipOf(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<IERC721A.TokenOwnershipStructOutput>;
    explicitOwnershipsOf(tokenIds: PromiseOrValue<BigNumberish>[], overrides?: CallOverrides): Promise<IERC721A.TokenOwnershipStructOutput[]>;
    getApproved(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<string>;
    getCosignNonce(minter: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
    getGlobalWalletLimit(overrides?: CallOverrides): Promise<BigNumber>;
    getMaxMintableSupply(overrides?: CallOverrides): Promise<BigNumber>;
    getNumberStages(overrides?: CallOverrides): Promise<BigNumber>;
    getStageInfo(index: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<[IERC721M.MintStageInfoStructOutput, number, BigNumber]>;
    isApprovedForAll(owner: PromiseOrValue<string>, operator: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
    mint(qty: PromiseOrValue<BigNumberish>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    mintWithLimit(qty: PromiseOrValue<BigNumberish>, limit: PromiseOrValue<BigNumberish>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    name(overrides?: CallOverrides): Promise<string>;
    ownerOf(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<string>;
    "safeTransferFrom(address,address,uint256)"(from: PromiseOrValue<string>, to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    "safeTransferFrom(address,address,uint256,bytes)"(from: PromiseOrValue<string>, to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, data: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    setApprovalForAll(operator: PromiseOrValue<string>, _approved: PromiseOrValue<boolean>, overrides?: Overrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    supportsInterface(interfaceId: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<boolean>;
    symbol(overrides?: CallOverrides): Promise<string>;
    tokenURI(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<string>;
    tokensOfOwner(owner: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber[]>;
    tokensOfOwnerIn(owner: PromiseOrValue<string>, start: PromiseOrValue<BigNumberish>, stop: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber[]>;
    totalMintedByAddress(a: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
    totalSupply(overrides?: CallOverrides): Promise<BigNumber>;
    transferFrom(from: PromiseOrValue<string>, to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        approve(to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<void>;
        authorizedMint(qty: PromiseOrValue<BigNumberish>, to: PromiseOrValue<string>, limit: PromiseOrValue<BigNumberish>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<void>;
        balanceOf(owner: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        crossmint(qty: PromiseOrValue<BigNumberish>, to: PromiseOrValue<string>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<void>;
        explicitOwnershipOf(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<IERC721A.TokenOwnershipStructOutput>;
        explicitOwnershipsOf(tokenIds: PromiseOrValue<BigNumberish>[], overrides?: CallOverrides): Promise<IERC721A.TokenOwnershipStructOutput[]>;
        getApproved(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<string>;
        getCosignNonce(minter: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        getGlobalWalletLimit(overrides?: CallOverrides): Promise<BigNumber>;
        getMaxMintableSupply(overrides?: CallOverrides): Promise<BigNumber>;
        getNumberStages(overrides?: CallOverrides): Promise<BigNumber>;
        getStageInfo(index: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<[IERC721M.MintStageInfoStructOutput, number, BigNumber]>;
        isApprovedForAll(owner: PromiseOrValue<string>, operator: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
        mint(qty: PromiseOrValue<BigNumberish>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<void>;
        mintWithLimit(qty: PromiseOrValue<BigNumberish>, limit: PromiseOrValue<BigNumberish>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<void>;
        name(overrides?: CallOverrides): Promise<string>;
        ownerOf(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<string>;
        "safeTransferFrom(address,address,uint256)"(from: PromiseOrValue<string>, to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<void>;
        "safeTransferFrom(address,address,uint256,bytes)"(from: PromiseOrValue<string>, to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, data: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<void>;
        setApprovalForAll(operator: PromiseOrValue<string>, _approved: PromiseOrValue<boolean>, overrides?: CallOverrides): Promise<void>;
        supportsInterface(interfaceId: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<boolean>;
        symbol(overrides?: CallOverrides): Promise<string>;
        tokenURI(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<string>;
        tokensOfOwner(owner: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber[]>;
        tokensOfOwnerIn(owner: PromiseOrValue<string>, start: PromiseOrValue<BigNumberish>, stop: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber[]>;
        totalMintedByAddress(a: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        totalSupply(overrides?: CallOverrides): Promise<BigNumber>;
        transferFrom(from: PromiseOrValue<string>, to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "Approval(address,address,uint256)"(owner?: PromiseOrValue<string> | null, approved?: PromiseOrValue<string> | null, tokenId?: PromiseOrValue<BigNumberish> | null): ApprovalEventFilter;
        Approval(owner?: PromiseOrValue<string> | null, approved?: PromiseOrValue<string> | null, tokenId?: PromiseOrValue<BigNumberish> | null): ApprovalEventFilter;
        "ApprovalForAll(address,address,bool)"(owner?: PromiseOrValue<string> | null, operator?: PromiseOrValue<string> | null, approved?: null): ApprovalForAllEventFilter;
        ApprovalForAll(owner?: PromiseOrValue<string> | null, operator?: PromiseOrValue<string> | null, approved?: null): ApprovalForAllEventFilter;
        "ConsecutiveTransfer(uint256,uint256,address,address)"(fromTokenId?: PromiseOrValue<BigNumberish> | null, toTokenId?: null, from?: PromiseOrValue<string> | null, to?: PromiseOrValue<string> | null): ConsecutiveTransferEventFilter;
        ConsecutiveTransfer(fromTokenId?: PromiseOrValue<BigNumberish> | null, toTokenId?: null, from?: PromiseOrValue<string> | null, to?: PromiseOrValue<string> | null): ConsecutiveTransferEventFilter;
        "SetActiveStage(uint256)"(activeStage?: null): SetActiveStageEventFilter;
        SetActiveStage(activeStage?: null): SetActiveStageEventFilter;
        "SetBaseURI(string)"(baseURI?: null): SetBaseURIEventFilter;
        SetBaseURI(baseURI?: null): SetBaseURIEventFilter;
        "SetCosigner(address)"(cosigner?: null): SetCosignerEventFilter;
        SetCosigner(cosigner?: null): SetCosignerEventFilter;
        "SetCrossmintAddress(address)"(crossmintAddress?: null): SetCrossmintAddressEventFilter;
        SetCrossmintAddress(crossmintAddress?: null): SetCrossmintAddressEventFilter;
        "SetGlobalWalletLimit(uint256)"(globalWalletLimit?: null): SetGlobalWalletLimitEventFilter;
        SetGlobalWalletLimit(globalWalletLimit?: null): SetGlobalWalletLimitEventFilter;
        "SetMaxMintableSupply(uint256)"(maxMintableSupply?: null): SetMaxMintableSupplyEventFilter;
        SetMaxMintableSupply(maxMintableSupply?: null): SetMaxMintableSupplyEventFilter;
        "SetMintCurrency(address)"(mintCurrency?: null): SetMintCurrencyEventFilter;
        SetMintCurrency(mintCurrency?: null): SetMintCurrencyEventFilter;
        "SetMintable(bool)"(mintable?: null): SetMintableEventFilter;
        SetMintable(mintable?: null): SetMintableEventFilter;
        "SetTimestampExpirySeconds(uint64)"(expiry?: null): SetTimestampExpirySecondsEventFilter;
        SetTimestampExpirySeconds(expiry?: null): SetTimestampExpirySecondsEventFilter;
        "Transfer(address,address,uint256)"(from?: PromiseOrValue<string> | null, to?: PromiseOrValue<string> | null, tokenId?: PromiseOrValue<BigNumberish> | null): TransferEventFilter;
        Transfer(from?: PromiseOrValue<string> | null, to?: PromiseOrValue<string> | null, tokenId?: PromiseOrValue<BigNumberish> | null): TransferEventFilter;
        "UpdateStage(uint256,uint80,uint80,uint32,bytes32,uint24,uint64,uint64)"(stage?: null, price?: null, mintFee?: null, walletLimit?: null, merkleRoot?: null, maxStageSupply?: null, startTimeUnixSeconds?: null, endTimeUnixSeconds?: null): UpdateStageEventFilter;
        UpdateStage(stage?: null, price?: null, mintFee?: null, walletLimit?: null, merkleRoot?: null, maxStageSupply?: null, startTimeUnixSeconds?: null, endTimeUnixSeconds?: null): UpdateStageEventFilter;
        "Withdraw(uint256)"(value?: null): WithdrawEventFilter;
        Withdraw(value?: null): WithdrawEventFilter;
        "WithdrawERC20(address,uint256)"(mintCurrency?: null, value?: null): WithdrawERC20EventFilter;
        WithdrawERC20(mintCurrency?: null, value?: null): WithdrawERC20EventFilter;
    };
    estimateGas: {
        approve(to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        authorizedMint(qty: PromiseOrValue<BigNumberish>, to: PromiseOrValue<string>, limit: PromiseOrValue<BigNumberish>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        balanceOf(owner: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        crossmint(qty: PromiseOrValue<BigNumberish>, to: PromiseOrValue<string>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        explicitOwnershipOf(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        explicitOwnershipsOf(tokenIds: PromiseOrValue<BigNumberish>[], overrides?: CallOverrides): Promise<BigNumber>;
        getApproved(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        getCosignNonce(minter: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        getGlobalWalletLimit(overrides?: CallOverrides): Promise<BigNumber>;
        getMaxMintableSupply(overrides?: CallOverrides): Promise<BigNumber>;
        getNumberStages(overrides?: CallOverrides): Promise<BigNumber>;
        getStageInfo(index: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        isApprovedForAll(owner: PromiseOrValue<string>, operator: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        mint(qty: PromiseOrValue<BigNumberish>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        mintWithLimit(qty: PromiseOrValue<BigNumberish>, limit: PromiseOrValue<BigNumberish>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        name(overrides?: CallOverrides): Promise<BigNumber>;
        ownerOf(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        "safeTransferFrom(address,address,uint256)"(from: PromiseOrValue<string>, to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        "safeTransferFrom(address,address,uint256,bytes)"(from: PromiseOrValue<string>, to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, data: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        setApprovalForAll(operator: PromiseOrValue<string>, _approved: PromiseOrValue<boolean>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        supportsInterface(interfaceId: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        symbol(overrides?: CallOverrides): Promise<BigNumber>;
        tokenURI(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        tokensOfOwner(owner: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        tokensOfOwnerIn(owner: PromiseOrValue<string>, start: PromiseOrValue<BigNumberish>, stop: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        totalMintedByAddress(a: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        totalSupply(overrides?: CallOverrides): Promise<BigNumber>;
        transferFrom(from: PromiseOrValue<string>, to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        approve(to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        authorizedMint(qty: PromiseOrValue<BigNumberish>, to: PromiseOrValue<string>, limit: PromiseOrValue<BigNumberish>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        balanceOf(owner: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        crossmint(qty: PromiseOrValue<BigNumberish>, to: PromiseOrValue<string>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        explicitOwnershipOf(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        explicitOwnershipsOf(tokenIds: PromiseOrValue<BigNumberish>[], overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getApproved(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getCosignNonce(minter: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getGlobalWalletLimit(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getMaxMintableSupply(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getNumberStages(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getStageInfo(index: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isApprovedForAll(owner: PromiseOrValue<string>, operator: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        mint(qty: PromiseOrValue<BigNumberish>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        mintWithLimit(qty: PromiseOrValue<BigNumberish>, limit: PromiseOrValue<BigNumberish>, proof: PromiseOrValue<BytesLike>[], timestamp: PromiseOrValue<BigNumberish>, signature: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        name(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        ownerOf(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        "safeTransferFrom(address,address,uint256)"(from: PromiseOrValue<string>, to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        "safeTransferFrom(address,address,uint256,bytes)"(from: PromiseOrValue<string>, to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, data: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        setApprovalForAll(operator: PromiseOrValue<string>, _approved: PromiseOrValue<boolean>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        supportsInterface(interfaceId: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        symbol(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        tokenURI(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        tokensOfOwner(owner: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        tokensOfOwnerIn(owner: PromiseOrValue<string>, start: PromiseOrValue<BigNumberish>, stop: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        totalMintedByAddress(a: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        totalSupply(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        transferFrom(from: PromiseOrValue<string>, to: PromiseOrValue<string>, tokenId: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
    };
}
